# No java support from EL-8 or F-37 (32 bit)
%if ( 0%{?fedora} > 36 &&  "%{_arch}" == "i386" ) || 0%{?rhel} > 7
%global java_support 0
%else
%global java_support 1
%endif

Summary:	Internationalized Domain Name support library
Name:		libidn
Version:	1.42
Release:	1.0%{?dist}
License:	(LGPL-3.0-or-later OR GPL-2.0-or-later) AND GPL-3.0-or-later AND GFDL-1.3-or-later
URL:		http://www.gnu.org/software/libidn
Source0:	https://ftp.gnu.org/gnu/libidn/libidn-%{version}.tar.gz
BuildRequires:	coreutils
#BuildRequires:	dblatex
BuildRequires:	emacs
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	gettext
BuildRequires:	gtk-doc
BuildRequires:	help2man
BuildRequires:	hostname
BuildRequires:	info
BuildRequires:	libtool
BuildRequires:	make
BuildRequires:	pkgconfig
BuildRequires:	sed
Requires:	emacs-filesystem >= %{_emacs_version}
# gnulib is a copylib; bundling is allowed
Provides:	bundled(gnulib)
Obsoletes:	emacs-libidn < %{version}-%{release}
Provides:	emacs-libidn = %{version}-%{release}

# Obsolete old java packages in environments where we no longer support them
%if 0%{?fedora:1} && !%{java_support} 
Obsoletes:	libidn-java < %{version}-%{release}
Obsoletes:	libidn-javadoc < %{version}-%{release}
%endif

# I hate autotools; it's so hard to patch Makefiles
#BuildRequires:	autoconf
#BuildRequires:	autoconf-archive
#BuildRequires:	automake
#BuildRequires:	libtool
#BuildRequires:	gettext-devel

%description
GNU Libidn is an implementation of the Stringprep, Punycode and IDNA
specifications defined by the IETF Internationalized Domain Names (IDN) working
group, used for internationalized domain names.

%if %{java_support} 
%package java
Summary:	Java port of the GNU Libidn library
BuildRequires:	java-devel
BuildRequires:	javapackages-local
BuildRequires:	mvn(com.google.guava:guava)
BuildRequires:	mvn(junit:junit)
BuildArch:	noarch

%description java
GNU Libidn is a fully documented implementation of the Stringprep,
Punycode and IDNA specifications. Libidn's purpose is to encode
and decode internationalized domain names.

This package contains the native Java port of the library.

%package javadoc
Summary:	Javadoc for libidn}-java
BuildArch:	noarch

%description javadoc
This package contains javadoc for libidn-java.
%endif

%package devel
Summary:	Development files for the libidn library
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	pkgconfig

%description devel
This package includes header files and libraries necessary for developing
programs that use the GNU libidn library.

%prep
%setup -q

# Appears to ship with broken autotools scripts
#autoreconf -ivf

%if %{java_support}
# Remove pre-built java stuff
find . -name '*.jar' -print -delete
find . -name '*.class' -print -delete

# Not available test dependency
%pom_remove_dep com.google.caliper:caliper java/pom.xml.in

# Unused dependency
%pom_remove_dep com.google.code.findbugs:annotations java/pom.xml.in
%endif

# Avoid dependency on /usr/bin/perl for devel package
chmod -c -x contrib/doxygen/gdoc2doxygen

# Remove file we don't want packaging
rm contrib/doxygen/Doxyfile.orig

# Note that the libidn.info file deliberately includes different character
# encodings and hence it's inappropriate to convert it to UTF-8

%build
%configure \
	--with-lispdir=%{_emacs_sitelispdir}/libidn \
	--disable-dependency-tracking \
	--disable-csharp \
%if %{java_support}
	--enable-java \
%else
	--disable-java \
%endif
	--libdir=%{_libdir}

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

%{make_build} WARN_CFLAGS="-Wall" V=1

%install
%{make_install} \
	INSTALL="install -p" \
	V=1 \
	WARN_CFLAGS="-Wall" \
	libidn_jardir=%{_javadir} \
	pkgconfigdir=%{_libdir}/pkgconfig \
	install

# Don't want to ship libtool and static libraries
rm -f %{buildroot}%{_libdir}/libidn.{a,la}

# Provide more examples
make %{?_smp_mflags} -C examples WARN_CFLAGS="-Wall" distclean

# Clean up docs
find doc -name "Makefile*" | xargs rm -f
rm -f %{buildroot}%{_datadir}/info/dir

%{_emacs_bytecompile} %{buildroot}%{_emacs_sitelispdir}/libidn/*.el

%if %{java_support}
# Regenerate java documentation
rm -rf doc/java/*
%javadoc -d doc/java $(find java/src/main/java -name "*.java")

# Generate maven depmap
rm -rf %{buildroot}%{_javadir}/libidn*.jar
%mvn_artifact java/pom.xml java/libidn-%{version}.jar
%mvn_file org.gnu.inet:libidn libidn
%mvn_install -J doc/java
%endif

%find_lang %{name}

%check
make %{?_smp_mflags} -C tests WARN_CFLAGS="-Wall" V=1 check

%files -f %{name}.lang
# GPL-2.0-or-later OR LGPL-3.0-or-later
%{_libdir}/libidn.so.12
%{_libdir}/libidn.so.12.*
# GPL-3.0-or-later
%license COPYING*
%doc ChangeLog NEWS FAQ README THANKS
%{_bindir}/idn
%{_emacs_sitelispdir}/libidn/
%{_infodir}/libidn.info.gz
%exclude %{_infodir}/libidn-components.png.gz
%{_mandir}/man1/idn.1*

%if %{java_support}
%files java -f .mfiles
%license COPYING* java/LICENSE-2.0.txt

%files javadoc -f .mfiles-javadoc
%license COPYING* java/LICENSE-2.0.txt
%endif

%files devel
# GPL-2.0-or-later OR LGPL-3.0-or-later
%{_includedir}/*.h
%{_libdir}/libidn.so
%{_libdir}/pkgconfig/*.pc
# GPL-3.0-or-later
%doc examples/ contrib/
%{_mandir}/man3/*
# GFDL-1.3-or-later
#doc doc/libidn.html
#doc doc/libidn.pdf

%changelog
* Mon Jan 15 2024 Paul Howarth <paul@city-fan.org> - 1.42-1.0
- Update to 1.42
  - Bump required gettext version to 0.19.8 for musl-libc
  - Compiler warning improvements
    - As before, compiler warnings are enabled by default
    - They may be disabled using ./configure --disable-gcc-warnings or turn
      them into fatal errors using ./configure --enable-gcc-warnings=error to
      add -Werror and sensible -Wno-error='s
    - Based on gnulib's manywarnings, see
      https://www.gnu.org/software/gnulib//manual/html_node/manywarnings.html
  - Fix type confusion on LLP64/Windows platforms
  - While libidn has worked using cygwin libc, it has never worked on
    ucrt/msvcrt libc; report and tiny patch by Francesco Pretto in
    https://lists.gnu.org/archive/html/help-libidn/2022-02/msg00000.html
  - tests: Added script tests/standalone.sh suitable for integrators
    - The main purpose is to test a system-installed libidn, suitable for
      distributor checking (à la Debian's autopkgtest/debci)
    - It may also be used to test a newly built libidn outside the usual
      'make check' infrastructure
    - To check that your system libidn is working, invoke the script with
      'srcdir' as an environment variable indicating where it can be find the
      source code for libidn's tests/ directory (it will use the directory
      name where the script is by default)
    - To check that a newly built static libidn behaves, invoke:
      env STANDALONE_CFLAGS="-Ilib lib/.libs/libidn.a" tests/standalone.sh
    - To check that a newly built shared libidn behaves, invoke:
      env srcdir=tests STANDALONE_CFLAGS="-Ilib -Wl,-rpath lib/.libs lib/.libs/libidn.so" tests/standalone.sh
    - If the libidn under testing is too old and has known bugs, that should
      cause tests to fail, which is intentional
  - Updated translations
  - Update gnulib files and build fixes
- Use SPDX-format license tag

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 1.41-5.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 1.41-4.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 1.41-3.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jul 15 2022 Paul Howarth <paul@city-fan.org> - 1.41-2.0
- Don't build java subpackages on i386 (#2104070)

* Mon Jun 27 2022 Paul Howarth <paul@city-fan.org> - 1.41-1.0
- Update to 1.41
  - Bump LT_REVISION for new release; it was mistakenly left at the same value
    since 1.38
  - Add version number related self-checks

* Tue Jun 21 2022 Paul Howarth <paul@city-fan.org> - 1.40-1.0
- Update to 1.40
  - lib: Code detecting current locale broken since 1.36
    - The code always returned ASCII; the precise cause is complicated to
      track down but likely boils down to the new autotools/gettext
      bootstrapping sequence introduced in release 1.36
  - maint: Java JAR archive no longer included in source tarball
  - Minor fixes: typos, makefiles, indentation, gnulib update, etc.
- Switch source URL to https

* Wed Feb  9 2022 Paul Howarth <paul@city-fan.org> - 1.38-4.0
- Rebuilt for java-17-openjdk as system jdk

* Fri Jan 21 2022 Paul Howarth <paul@city-fan.org> - 1.38-3.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Jul 26 2021 Paul Howarth <paul@city-fan.org> - 1.38-1.0
- Update to 1.38
  - Documentation: Simplify building of gdoc-generated man/texi outputs; now
    the targets are rebuilt on version number changes properly
  - Documentation: Improve GTK-DOC manual
  - Build: Fix build errors related to doc/idn--help.texi
  - Build: Fix --disable-tld builds; now, tld_strerror() is removed when
    --disable-tld is used

* Thu Jul 22 2021 Paul Howarth <paul@city-fan.org> - 1.37-3.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Thu Jun  3 2021 Paul Howarth <paul@city-fan.org> - 1.37-2.0
- Remove unnecessary findbugs dependency (#1966769)

* Mon May 17 2021 Paul Howarth <paul@city-fan.org> - 1.37-1.0
- Update to 1.37
  - Documentation: Minor fixes and codespell typos
  - Updated translations
  - Update gnulib files and build fixes (we now use gnulib's ./bootstrap and
    gnulib's readme-release infrastructure for making releases)
- Upstream did not ship doc/libidn.html or doc/libidn.pdf in this release

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 1.36-2.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Jul 23 2020 Paul Howarth <paul@city-fan.org> - 1.36-1.0
- Update to 1.36
  - Fix unlikely memory leak in idna_to_unicode_4z4z()
  - Check codepoint validity in punycode_encode() and punycode_decode()
  - tld: Add U+00EF to .nl TLD table
  - Indent code
  - Translation fixes
  - Update gnulib files
- Modernize spec using %%{make_build} and %%{make_install}

* Tue Jul 21 2020 Paul Howarth <paul@city-fan.org> - 1.35-9.0
- Rebuilt for JDK-11 (https://fedoraproject.org/wiki/Changes/Java11)

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 1.35-8.0
- Fix build with JDK11

* Thu Jan 30 2020 Paul Howarth <paul@city-fan.org> - 1.35-7.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 1.35-6.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.35-5.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Nov 18 2018 Paul Howarth <paul@city-fan.org> - 1.35-3.1
- Disable java for EL-8 build

* Tue Jul 17 2018 Paul Howarth <paul@city-fan.org> - 1.35-3.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 26 2018 Paul Howarth <paul@city-fan.org> - 1.35-2.0
- Drop support for older distributions prior to Fedora 29
  - %%license is always available
  - Never need ldconfig scriptlets
  - Emacs bytecode always multilib-safe
  - Always build java bindings
  - Always installing to %%{_libdir}
  - hostname package always exists
  - Drop obsolete install-info scriptlets

* Mon May 14 2018 Paul Howarth <paul@city-fan.org> - 1.35-1.0
- Update to 1.35
  - Reflect ABI/API breakage in version 1.34 (Stringprep_profile has a new
    struct member)
  - Added new gnulib files to repository

* Tue May  8 2018 Paul Howarth <paul@city-fan.org> - 1.34-2.0
- Fix ABI compatibility with libidn-1.33 and earlier (#1566414, #1573961)

* Tue Apr  3 2018 Paul Howarth <paul@city-fan.org> - 1.34-1.0
- Update to 1.34
  - Fix various libidn issues found by fuzzing:
    - Integer overflow in combine_hangul()
    - Integer overflow in punycode decoder
    - Performance issue in idna_to_unicode_internal()
    - Performance issue in stringprep functions
    - NULL pointer dereference in g_utf8_normalize()
    - NULL pointer dereference in stringprep_ucs4_nfkc_normalize()
    - Increase performance of stringprep functions
  - testing: Add OSS-fuzz integration and regression testing
  - build: Update gnulib files
  - build: Modernize GTK-Doc build
  - build: Fix parallel builds
  - build: Add configure flag --disable-doc
  - build: Add configure flag --enable-ubsan (enable UB Sanitizer)
  - build: Add configure flag --enable-asan (enable Address Sanitizer)
  - build: Fix compiler warnings
  - build: Fix build for gcc-7
  - i18n: Added Swedish translation

* Fri Mar  2 2018 Paul Howarth <paul@city-fan.org> - 1.33-6.0
- ldconfig replaced by RPM File Triggers from Fedora 28

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 1.33-4.0
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sun Feb 12 2017 Paul Howarth <paul@city-fan.org> - 1.33-2.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jul 21 2016 Paul Howarth <paul@city-fan.org> - 1.33-1.0
- Update to 1.33
  - libidn: Fix out-of-bounds stack read in idna_to_ascii_4i
  - idn: Solve out-of-bounds-read when reading one zero byte as input; also
    replaced fgets with getline
  - libidn: stringprep_utf8_nfkc_normalize now rejects invalid UTF-8; it was
    always documented to only accept UTF-8 data, but now it doesn't crash when
    presented with such data
  - Dropped valgrind suppressions file, should no longer be needed

* Wed Jun 22 2016 Paul Howarth <paul@city-fan.org> - 1.32-3.0
- Specify all build requirements

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.32-2.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Aug  3 2015 Paul Howarth <paul@city-fan.org> - 1.32-1.0
- Update to 1.32
  - libidn: Fix crash in idna_to_unicode_8z8z and idna_to_unicode_8zlz

* Thu Jul  9 2015 Paul Howarth <paul@city-fan.org> - 1.31-1.0
- Update to 1.31
  - libidn: stringprep_utf8_to_ucs4 now rejects invalid UTF-8 (CVE-2015-2059);
    see NEWS for discussion of implications
  - libidn: Added STRINGPREP_ICONV_ERROR error code
  - libidn: Work around valgrind/gcc/glibc issue
  - build: Use LOG_COMPILER instead of TESTS_ENVIRONMENT to fix valgrind use
  - i18n: Updated Danish translation

* Sat Jul  4 2015 Paul Howarth <paul@city-fan.org> - 1.30-4.1
- Unmerge emacs-libidn for Fedora 19 and older releases due to multilib
  conflicts (see #1122157)

* Sat Jun 27 2015 Paul Howarth <paul@city-fan.org> - 1.30-4
- Merge emacs-libidn with main package (#1234563)

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 1.30-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 31 2015 Paul Howarth <paul@city-fan.org> - 1.30-2
- Build java bindings for Fedora 20 onwards

* Mon Mar  2 2015 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - libidn: the punycode.{c,h} files were re-imported from RFC 3492bis; a
    comment explaining the origin and what was changed was added
  - Bump gettext to 0.19.3
  - Use LT_INIT instead of AC_LIBTOOL_WIN32_DLL
  - i18n: added Hungarian translation; updated some other languages

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 1.29-3
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.29-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 15 2014 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Mark internal variable "g_utf8_skip" as static
  - idn: flush stdout to simplify for tools that buffer too heavily
  - Add Brazilian Portuguese translation
  - Update gnulib files

* Mon Jul 21 2014 Paul Howarth <paul@city-fan.org> - 1.28-4
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4

* Wed Jan 15 2014 Paul Howarth <paul@city-fan.org> - 1.28-3
- BR: hostname package rather than /bin/hostname from F-21 as the latter is no
  longer provided in rawhide

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.28-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jul 11 2013 Paul Howarth <paul@city-fan.org> 1.28-1
- Update to 1.28
  - Don't crash when string conversion from UTF-8 to locale fails
  - Fix java build failures
  - java: TestIDNA -a and -u logic was reversed, now fixed

* Sun Jun  9 2013 Paul Howarth <paul@city-fan.org> 1.27-1
- Update to 1.27
  - Java library can be built using Maven
  - Speed improvements
  - Update gnulib files and translations
- Make devel dependency arch-specific

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> 1.26-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec 17 2012 Paul Howarth <paul@city-fan.org> 1.26-1
- Update to 1.26
  - Propagate error on malloc failure
  - Fix out of bounds read access violation
  - Added Croatian translation
  - Updated Vietnamese translation
  - Permit usage of java binding by Apache projects
  - Improve tld self-tests
- BR: /bin/hostname (for configure test)

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> 1.25-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 30 2012 Paul Howarth <paul@city-fan.org> 1.25-2
- Provide bundled(gnulib) (#821768)

* Thu May 24 2012 Paul Howarth <paul@city-fan.org> 1.25-1
- Update to 1.25
  - Fix build with MSVC related to _GL_ATTRIBUTE_CONST and _GL_ATTRIBUTE_PURE
  - Fix compiler warning about ignoring return value from fgets in examples
  - Ship with a valgrind suppressions file for the strlen issue in the tests
  - Update gnulib files and translations
- Build with V=1 so we can see the compiler flags being used

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> 1.24-2
- From F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Maintain upstream timestamps where possible

* Wed Jan 11 2012 Paul Howarth <paul@city-fan.org> 1.24-1
- Update to 1.24
  - Libraries are re-licensed from LGPLv2+ to dual-GPLv2+|LGPLv3+
  - Fix parallel Windows builds
  - libidn: Fix potential infloop in pr29 code
    (http://lists.gnu.org/archive/html/help-libidn/2012-01/msg00008.html)
  - libidn: Add 'const' keyword to 'stringprep_ucs4_nfkc_normalize' function
  - Sync glib NFKC code and improve copyright/license statements
  - Update gnulib files and translations

* Fri Nov 25 2011 Paul Howarth <paul@city-fan.org> 1.23-1
- Update to 1.23
  - stringprep.h: Now #include's sys/types.h instead of unistd.h for ssize_t
    (some systems e.g., Mingw with MSVC 9, do not have unistd.h)
  - idn-free.h: Protect prototypes with 'extern "C"' marker
  - doc: Update link to experimental TLD tables:
    the new link is <https://github.com/gnuthor/tldchk>
  - Update gnulib files and translations
  - QA: Improved cyclo output, update GTK-DOC files, various bugfixes

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> 1.22-3
- Split emacs-libidn subpackage to avoid *.elc arch conflicts (#709136)

* Sun May 29 2011 Paul Howarth <paul@city-fan.org> 1.22-2
- Byte compile Emacs lisp files, require emacs-filesystem for dir ownership

* Thu May  5 2011 Paul Howarth <paul@city-fan.org> 1.22-1
- Update to 1.22
  - libidn: Add -liconv as static library requirement in libidn.pc, for MinGW
  - libidn: Fix memory leak in idna_to_ascii_4z when idna_to_ascii_4i fails
  - libidn: Ran clang-analyze on the code; fixed some dead
    assignments/initializations
  - build: Really distribute win32/libidn4win.mk

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> 1.21-1
- Update to 1.21
  - build/gettext: Demand gettext >= 0.18.1 in order to get newer M4 files; the
    old M4 files associated with 0.17 caused problems on Solaris
    (http://thread.gmane.org/gmane.comp.lib.gnulib.bugs/25522)
  - build: Improve MinGW cross-compile makefile, see win32/libidn4win.mk
  - build: Visual Studio files fixed to define LIBIDN_BUILDING
- Nobody else likes macros for commands

* Wed Mar  2 2011 Paul Howarth <paul@city-fan.org> 1.20-1
- Update to 1.20
  - libidn: fix bug in ToUnicode to compare 'xn--' case-insensitively
    (http://bugs.debian.org/610617)
  - add self-test tst_idna3 to catch any regression of problem above
  - idn: only print copyright and license blurb when used interactively
    (http://bugs.debian.org/615947 and http://bugs.debian.org/615949)
  - update gnulib files and translations

* Mon Aug  2 2010 Paul Howarth <paul@city-fan.org> 1.19-2
- Move library to /%%{_lib} for F-9, EL-6 onwards (#283651)
- Don't package %%{_infodir}/libidn-components.png
- BR: symlinks

* Mon May 24 2010 Paul Howarth <paul@city-fan.org> 1.19-1
- Update to 1.19
  - fix typos in docs
  - add PDF version of API reference manual
  - update gnulib files
  - use valgrind -q in build to reduce verbosity

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> 1.18-1
- Update to 1.18 (fix symbol export problem for a few variables)
- Fix doc file dependency on /usr/bin/perl for devel package

* Wed Jan 13 2010 Paul Howarth <paul@city-fan.org> 1.16-1
- Update to 1.16 (add a Maven pom.xml, not packaged)

* Tue Jun  9 2009 Paul Howarth <paul@city-fan.org> 1.15-1
- Update to 1.15
- * use c_strcasecmp instead of strcasecmp (spec requires ASCII comparison)
- * some java compiler warnings fixed
- * improved sections for the info manual
- No need to clean up info file sections any longer

* Mon Apr  6 2009 Paul Howarth <paul@city-fan.org> 1.14-1
- Update to 1.14 (test updates and extra data for Windows platform)

* Mon Mar  9 2009 Paul Howarth <paul@city-fan.org> 1.13-1
- Update to 1.13 (improvements in symbol visibility and dependencies)

* Mon Jan 26 2009 Paul Howarth <paul@city-fan.org> 1.12-1
- Update to 1.12
- Manual now licensed GFDL 1.3 or later
- Specify WARN_CFLAGS=-Wall to prevent the use of options unsupported on old
  releases

* Tue Oct 28 2008 Paul Howarth <paul@city-fan.org> 1.11-1
- Update to 1.11

* Wed Aug 27 2008 Paul Howarth <paul@city-fan.org> 1.10-1
- Update to 1.10
- Source is now on ftp.gnu.org

* Fri Jul  4 2008 Paul Howarth <paul@city-fan.org> 1.9-2
- Use /%%{_lib} rather than %%{_lib} in the bogus RPATH killer script

* Wed Jul  2 2008 Paul Howarth <paul@city-fan.org> 1.9-1
- Update to 1.9

* Thu Apr 24 2008 Paul Howarth <paul@city-fan.org> 1.8-1
- Update to 1.8

* Fri Apr 11 2008 Paul Howarth <paul@city-fan.org> 1.7-1
- Update to 1.7

* Tue Mar 25 2008 Paul Howarth <paul@city-fan.org> 1.6-1
- Update to 1.6

* Wed Feb 20 2008 Paul Howarth <paul@city-fan.org> 1.5-1
- Update to 1.5
- Using system libtool results in build failures, so hack the supplied libtool
  to prevent the generation of bogus RPATHs on 64-bit systems instead

* Fri Jan 11 2008 Paul Howarth <paul@city-fan.org> 1.4-1
- Update to 1.4

* Tue Dec 11 2007 Paul Howarth <paul@city-fan.org> 1.3-1
- Update to 1.3

* Tue Oct  2 2007 Paul Howarth <paul@city-fan.org> 1.2-1
- Update to 1.2

* Tue Sep 11 2007 Paul Howarth <paul@city-fan.org> 1.1-1
- Update to 1.1
- Clarify licensing in more detail

* Tue Jul 31 2007 Paul Howarth <paul@city-fan.org> 1.0-1
- Update to 1.0
- Add note regarding licensing in License: tag

* Thu May 31 2007 Paul Howarth <paul@city-fan.org> 0.6.14-1
- Update to 0.6.14
- Include %%{_infodir}/libidn-components.png.gz

* Thu Apr 26 2007 Paul Howarth <paul@city-fan.org> 0.6.12-1
- Update to 0.6.12

* Thu Mar 15 2007 Paul Howarth <paul@city-fan.org> 0.6.11-1
- Update to 0.6.11

* Fri Jan  5 2007 Paul Howarth <paul@city-fan.org> 0.6.10-1
- Update to 0.6.10

* Fri Dec  1 2006 Paul Howarth <paul@city-fan.org> 0.6.9-1
- Update to 0.6.9

* Fri Nov 17 2006 Paul Howarth <paul@city-fan.org> 0.6.8-3
- Let's try to remember to sign the package this time

* Thu Nov 16 2006 Paul Howarth <paul@city-fan.org> 0.6.8-2
- use non-GNU section in info directory (#209491)

* Thu Oct 19 2006 Paul Howarth <paul@city-fan.org> 0.6.8-1
- update to 0.6.8

* Thu Sep 14 2006 Paul Howarth <paul@city-fan.org> 0.6.7-1
- update to 0.6.7
- use system libtool to avoid rpath of /usr/lib64 in idn, provided that
  it supports all required options
- add note about encoding of info file

* Fri Aug 25 2006 Paul Howarth <paul@city-fan.org> 0.6.6-1
- update to 0.6.6

* Mon Jul 10 2006 Paul Howarth <paul@city-fan.org> 0.6.5-1
- update to 0.6.5

* Fri Jul  7 2006 Paul Howarth <paul@city-fan.org> 0.6.4-1
- update to 0.6.4
- was going to add valgrind buildreq for improved test coverage but some
  old distros I'd like to support (e.g. RHL9) don't have valgrind

* Thu Apr  6 2006 Paul Howarth <paul@city-fan.org> 0.6.3-2
- rewrite spec in Fedora Extras style
- add dist tag to facilitate separate build for Fedora Core 5 and later
  (#188006)
- exclude libtool archive and static library
- explicitly disable C# and Java bindings

* Wed Apr  5 2006 Paul Howarth <paul@city-fan.org> 0.6.3-1
- remove the unpackaged DLL if it gets installed

* Thu Mar  9 2006 Paul Howarth <paul@city-fan.org> 0.6.3-0
- update to 0.6.3

* Wed Feb  8 2006 Paul Howarth <paul@city-fan.org> 0.6.2-0
- update to 0.6.2

* Fri Dec  2 2005 Paul Howarth <paul@city-fan.org> 0.6.0-0
- update to 0.6.0

* Mon Oct 24 2005 Paul Howarth <paul@city-fan.org> 0.5.20-0
- update to 0.5.20

* Tue Sep 20 2005 Paul Howarth <paul@city-fan.org> 0.5.19-0
- update to 0.5.19

* Fri May 27 2005 Paul Howarth <paul@city-fan.org> 0.5.17-0
- update to 0.5.17

* Wed May 11 2005 Paul Howarth <paul@city-fan.org> 0.5.16-0
- update to 0.5.16

* Sun Mar 20 2005 Joe Orton <jorton@redhat.com> 0.5.15-1
- update to 0.5.15

* Fri Mar  4 2005 Joe Orton <jorton@redhat.com> 0.5.13-2
- rebuild

* Mon Jan 31 2005 Joe Orton <jorton@redhat.com> 0.5.13-1
- update to 0.5.13

* Sun Dec  5 2004 Joe Orton <jorton@redhat.com> 0.5.12-1
- update to 0.5.12

* Mon Nov 29 2004 Joe Orton <jorton@redhat.com> 0.5.11-1
- update to 0.5.11 (#141094)

* Tue Nov  9 2004 Joe Orton <jorton@redhat.com> 0.5.10-1
- update to 0.5.10
- buildroot cleanup fix (Robert Scheck)

* Mon Nov  8 2004 Joe Orton <jorton@redhat.com> 0.5.9-1
- update to 0.5.9 (#138296)

* Thu Oct  7 2004 Joe Orton <jorton@redhat.com> 0.5.6-1
- update to 0.5.6 (#134343)

* Thu Sep 30 2004 Miloslav Trmac <mitr@redhat.com> - 0.5.4-3
- Fix Group: (#134068)

* Tue Aug 31 2004 Joe Orton <jorton@redhat.com> 0.5.4-2
- move ldconfig from preun to postun (#131280)

* Sun Aug  8 2004 Joe Orton <jorton@redhat.com> 0.5.4-1
- update to 0.5.4 (#129341)

* Thu Jul 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.5.2-1
- upgrade to 0.5.2, enabled i18n support and info files (#127906)

* Fri Jul  9 2004 Joe Orton <jorton@redhat.com> 0.5.1-1
- update to 0.5.1 (#127496)

* Mon Jun 28 2004 Joe Orton <jorton@redhat.com> 0.5.0-1
- update to 0.5.0 (#126836)

* Tue Jun 22 2004 Than Ngo <than@redhat.com> 0.4.9-2
- add prereq: /sbin/ldconfig
- move la file in main package

* Tue Jun 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.4.9-1
- upgrade to 0.4.9 (#126353)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.4-1
- update to 0.4.4; remove contrib from -devel docs

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.3-1
- update to 0.4.3, remove -rpath patch

* Tue Jan 27 2004 Joe Orton <jorton@redhat.com> 0.3.7-1
- update to 0.3.7, simplify

* Wed Jan 07 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.3.6-1mdk
- 0.3.6

* Mon Dec 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.5-1mdk
- 0.3.5

* Sun Oct 19 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-2mdk
- drop the "soname fix" and use the correct way...

* Sat Oct 18 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-1mdk
- 0.3.3

* Mon Oct 13 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.2-1mdk
- initial cooker contrib
- used the package from PLD as a start point
